@@ -70,9 +70,12 @@ def new_image(
     return image_sprite
 
 def new_text(
-    text, x=0, y=0, z=0, top=None, bottom=None, right=None, left=None, angle=0,
+    text=None, words=None, x=0, y=0, z=0, top=None, bottom=None, right=None, left=None, angle=0,
     font=None, font_size=50, color='black', is_hidden=False
 ):
+    assert text is not None or words is not None, "either text or words should be passed to new_text()"
+    if words is not None: text = words
+
     text = _Text(_sprite_manager, text, x, y, z, angle, font, font_size, color)
     _position_sprite(text, top, bottom, right, left)
     text.is_hidden = is_hidden
@@ -154,6 +157,12 @@ def foreach_sprite(*sprites, tag=None):
         return func
     return decorator
 
+def when_sprite_clicked(*sprites):
+    def decorator(func):
+        for sprite in sprites:
+            sprite.when_clicked(func, call_with_sprite=True)
+    return decorator
+
 async def sleep(seconds=1.0):
     """
     Wait a number of seconds. Used with the await keyword like this:
@@ -176,4 +185,9 @@ def start_program():
     try:
         _task_runner.loop.run_forever()
     finally:
-        _pygame.quit()
\ No newline at end of file
+        _pygame.quit()
+
+# aliasing to achieve compatibility with replit-play api
+# TODO: add nyan.backdrop
+timer = sleep
+new_box = new_rect
